=======
CHANGES
=======

0.0.3 (2019-01-25)
------------------

- Supports new pytest-play >= 2.0 YAML based syntax (json no more supported)

- No more payload parmeter is json encodable


0.0.2 (2018-01-10)
------------------

- Commands accept kwargs now


0.0.1 (2018-01-04)
------------------

* First release
